using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using Unity.Mathematics;

/// <summary>
/// During the initial generation of terrain,
/// a height map is created. The heightMin
/// corrosponds to the minimum heights
/// the biome can be created at. As such, biomes
/// with a larger heightMin tend to be smaller.
/// </summary>
[System.Serializable]
public struct Biome
{
    [Tooltip("The range of temperatures where this biome can generate.")]
    public Vector2 temperatureRange;
    [Tooltip("The range of moistures where this biome can generate.")]
    public Vector2 moistureRange;
    [Tooltip("The range of magic this biome can generate. Reserved for special biomes.")]
    public Vector2 magicRange;
    [Tooltip("Larger value means more likely to be selected if two different biomes could be selected.")]
    public float probablity;
    public List<Octave> octaves;
}

public class BiomeGenerator : TerrainGenerator
{
    [Header("Biome settings")]
    [Tooltip("Larger values mean smaller/more biomes.")]
    public float biomeGenerationFrequency = 1;
}
